export type PayMethod = {
    label: string;
    value: PayType,
    icon: string;
    disabled: boolean
}

export const BACK_PAY_ID = 'backPayId'

export const BACK_ORDER_ID = 'backOrderId'

export type BackInfo = {
    orderId: number;
    payId: number
}
export type OrderStateCallBack = (params: BackInfo & { isPay: boolean }) => void

export const enum PayType {
    /**
     * 余额支付
     */
    BALANCE = 1,
    /**
     * 微信支付
     */
    WECHAT = 5,
    /**
     * 支付宝支付
     */
    ALIPAY = 6,
    /**
     * 微信 + 余额支付
     */
    WECHAT_BALANCE = 7,
    /**
     * 支付宝 + 余额支付
     */
    ALIPAY_BALANCE = 8,
    /**
     * 花呗支付
     */
    HUABEI = 10,
    /**
     * 花呗 + 余额支付
     */
    HUABEI_BALANCE = 11,
    /**
     * 花呗分期
     */
    HUABEI_STAGE = 12,
    /**
     * 花呗分期 + 余额支付
     */
    HUABEI_STAGE_BALANCE = 13

}

export const enum PayChannel {
    WX_MWEB = 'WX_MWEB',
    WX_JSAPI = 'WX_JSAPI',
    WX_NATIVE = 'WX_NATIVE',
    WX_APP = 'WX_APP',
    ALI_WAP = 'ALI_WAP',
    ALI_APP = 'ALI_APP',
    ALI_PC = 'ALI_PC',
    ALI_QR = 'ALI_QR',
    ALI_PCREDIT = 'ALI_PCREDIT'
}

export type ToPayParams = {
    orderId: number;
    totalAmount: number
    payType: PayType;
    /**
     * 支付宝h5支付失败回调地址
     * doc: https://opendocs.alipay.com/open/203/105285#%E9%87%8D%E8%A6%81%E5%85%A5%E5%8F%82%E8%AF%B4%E6%98%8E_3
     */
    quitUrl: string;
    /**
     * 支付宝h5支付成功回调地址
     * doc: https://opendocs.alipay.com/open/203/105285#%E9%87%8D%E8%A6%81%E5%85%A5%E5%8F%82%E8%AF%B4%E6%98%8E_3
     */
    returnUrl: string;
    /**
     * 微信h5支付回调地址
     * doc: https://pay.weixin.qq.com/wiki/doc/apiv3/wxpay/pay/combine/chapter10_1.shtml
     */
    redirectUrl: string
}

export enum PayError {
    WECHAT_JSSDK = "WECHAT_JSSDK",
    BALANCE = 'BALANCE',
    VALIDATE = 'VALIDATE',
    BACKEND = 'BACKEND'
}

export type ToPayReturns = {
    errorMessage?: string
    errorType: PayError
    success: boolean
}

export interface DoUnifiedParams extends Omit<ToPayParams, 'totalAmount' | 'redirectUrl'> {
    payChannel?: PayChannel,
    payBalance: number,
    payAmount: number
}

export interface WechatPayParams {
    appId: string,
    timeStamp: string,
    nonceStr: string,
    signType: string,
    paySign: string,
    package: string
}

export const FULL_PAY_METHODS: PayMethod[] = [
    {
        label: '余额',
        value: PayType.BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/icon-pay-qb.png',
        disabled: false
    },
    {
        label: '微信支付',
        value: PayType.WECHAT,
        icon: 'https://static.ydlcdn.com/m/order/icon-pay-wx.png',
        disabled: false
    },
    {
        label: '支付宝支付',
        value: PayType.ALIPAY,
        icon: 'https://static.ydlcdn.com/m/order/icon-pay-zfb.png',
        disabled: false
    },
    {
        label: '微信支付',
        value: PayType.WECHAT_BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/icon-pay-wx.png',
        disabled: false
    },
    {
        label: '支付宝支付',
        value: PayType.ALIPAY_BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/icon-pay-zfb.png',
        disabled: false
    },
    {
        label: '花呗支付',
        value: PayType.HUABEI,
        icon: 'https://static.ydlcdn.com/m/order/icon-pay-hb.png',
        disabled: false
    },
    {
        label: '花呗支付',
        value: PayType.HUABEI_BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/icon-pay-hb.png',
        disabled: false
    }
]